@@ -4,11 +4,11 @@ from office.lib.utils.except_utils import except_dec
 mainMarkdown = MainMarkdown()
 
 
-@except_dec()
+# @except_dec()
 def markdown_link_image_to_base64(markdown_path):
     mainMarkdown.markdown_link_image_to_base64(markdown_path)
 
 
-@except_dec()
+# @except_dec()
 def check_local_dir_image_link_markdown(markdown_path, image_path):
     mainMarkdown.check_local_dir_image_link_markdown(markdown_path, image_path)
\ No newline at end of file
